@@ -1,6 +1,6 @@
 package Reddit::Client;
 
-our $VERSION = '1.0902'; 
+our $VERSION = '1.093'; 
 $VERSION = eval $VERSION;
 
 use strict;
@@ -186,17 +186,19 @@ use fields (
     	'secret',
 	'username',
 	'password',
+	'request_errors',
 );
 
 sub new {
-    my ($class, %param) = @_;
-    my $self = fields::new($class);
+	my ($class, %param) = @_;
+	my $self = fields::new($class);
 
-    if (not exists $param{user_agent}) {
-        carp "Reddit::Client->new: user_agent required in future version.";
-        $param{user_agent} = $UA;
-    }
-    $self->{user_agent} = $param{user_agent};
+	if (not exists $param{user_agent}) {
+		carp "Reddit::Client->new: user_agent required in future version.";
+		$param{user_agent} = $UA;
+	}
+	$self->{user_agent} = $param{user_agent};
+	$self->{request_errors}= $param{request_errors} || 0;
 
 	if ($param{username} || $param{password} || $param{client_id} || $param{secret}) {
 		if (!$param{username} || !$param{password} || !$param{client_id} || !$param{secret}) {
@@ -211,6 +213,7 @@ sub new {
 		}
 	}
 
+	#print Dumper $self;
     return $self;
 }
 
@@ -235,8 +238,7 @@ sub request {
     my $request = Reddit::Client::Request->new(
         user_agent => $self->{user_agent},
 		   # path is sprintf'd before call, in api_json_request
-		   # the calling function passes in path %s's in 'args' param, 
-		   # an array REFERENCE
+		   # the calling function passes in path %s's in 'args' param 
         url        => sprintf('%s/%s', $BASE_URL, $path),
         method     => $method,
         query      => $query,
@@ -245,6 +247,7 @@ sub request {
         cookie     => $self->{cookie},
 	token	   => $self->{token},
 	tokentype  => $self->{tokentype},
+	request_errors=> $self->{request_errors},
     );
 
     return $request->send;
@@ -314,12 +317,6 @@ sub api_json_request {
 
     my $info   = $API[$api] || croak "Unknown API: $api";
     my ($method, $path) = @$info;
-	#if ($param{test}) {
-	#	use Data::Dump::Color;
-	#	dd $path;
-	#	dd @$args;
-	#	dd %param;
-	#}
     $path = sprintf $path, @$args;
 
     my ($query, $post_data);
