@@ -19,7 +19,8 @@ use fields (
     'cookie',
     'modhash',
     'token',
-    'tokentype'
+    'tokentype',
+	'request_errors',
 );
 
 sub new {
@@ -33,6 +34,7 @@ sub new {
     $self->{modhash}    = $param{modhash};
     $self->{token}	= $param{token};
     $self->{tokentype}	= $param{tokentype};
+	$self->{request_errors}= $param{request_errors} || 0;
 
     if (defined $self->{query}) {
         ref $self->{query} eq 'HASH' || croak 'Expected HASH ref for "query"';
@@ -99,7 +101,11 @@ sub send {
     if ($res->is_success) {
         return $res->content;
     } else {
-        croak "Request error: HTTP ".$res->status_line .", Content: $res->{_content}";
+	if ($self->{request_errors}) {
+        	croak "Request error: HTTP ".$res->status_line .", Content: $res->{_content}";
+	} else {
+		croak sprintf('Request error: HTTP %s', $res->status_line);
+	}
     }
 }
 
